| TDR | R Documentation |
TDR performs the time-dose-response analysis pipeline as
presented in Duda et al. (2021). That is: For a dose-response or
concentration-response data set where, additionally also the (exposure)
time is varied, this procedure can be applied. The main aim of this
procedure are cytotoxicity data.
The approach is divided into two steps. In step one, it is tested in a
nested ANOVA if the (exposure) time has an influence on the dose-response
relationship. In case of a significant results, the time-dose two-parameter
log-logistic model is fitted to the data:
f(d,t)=100-100\frac{d^h}{EC_{50}(t)^h + d^h}
with
EC_{50}(t) = Δ \cdot t^{-γ} + C_0.
If no significant result is obtained, a dose-response 2pLL curve is fitted, ignoring the information on (exposure) time.
TDR(data, alpha = 0.05, strict_stop = FALSE, ...)
data |
(Numeric |
alpha |
( |
strict_stop |
( |
... |
Further arguments that can be passed on to |
For further details on the td2pLL model, check fit_td2pLL().
For details on the ANOVA used, see td2pLL_anova(). More over,
the entire procedure is explained in duda et al. (2021).
A list with entries pretest and fit.
pretest is captures the anova based pre-test result as a list with
entires signif (TRUE/FALSE or NA if no-convergence), alpha,
anova_res (the anova result from function anova) and
conv (logical: If the pre-test converged).
fit Is, depending on the pre-test, either an object of class
td2pLL or a 2pLL fit, i.e. an object of class drc.
data(cytotox)
data_subset <- cytotox[cytotox$compound == "ASP", c("expo", "dose", "resp")]
colnames(data_subset)[1] <- "time"
TDR_res <- TDR(data = data_subset)
# Pre-test rejected time dependency, so a regular 2pLL model is the result
plot(TDR_res$fit)
data_subset <- cytotox[cytotox$compound == "CHL", c("expo", "dose", "resp")]
colnames(data_subset)[1] <- "time"
TDR_res <- TDR(data = data_subset)
# Pre-test did not reject time dependency, so a td2pLL model is the result
# Note that the interactive Plot is in the Viewer panel, not in the Plots panel
plot(TDR_res$fit)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.