View source: R/get_starting_values.R
| get_starting_values | R Documentation |
Calculates (cheap) default starting values for fitting a td2pLL model based on dose time response data.
get_starting_values(data, h_start = 2, c0_start = 0)
data |
(numeric |
h_start |
( |
c0_start |
( |
As starting value for delta and gamma, a pair of
cheap starting values of (dose, ED50) at the lowest and the highest
(exposure) time are calculated via the interp_ED50() function.
With these two pairs (dose_1, ED50_1) and (dose_2, ED50_2), as
well as the set starting values of h and c0,
the model equation of the td2pLL model
f(d,t)=100-100\frac{d^h}{EC_{50}(t)^h + d^h},
EC_{50}(t) = Δ \cdot t^{-γ} + C_0
is solved to get the starting values gamma_start and
delta_start for gamma and delta.
(list(4))
List with starting values for h, delta, gamma and c0.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.