View source: R/icaodOptDesign.R
| td_opt | R Documentation |
If prior knowledge on the (rough) model shape is available, an optimal experimental design for a td2pLL model can be calculated. The numerical back bone is the Imperialist Competitive Algorithm implemented by Masoudi et al (2017).
td_opt( param, Emax_known = FALSE, lx = c(1, exp(-8)), ux = c(10, 1), iter = 1000, ICA.control = NULL )
param |
( |
Emax_known |
( |
lx |
( |
ux |
( |
iter |
( |
ICA.control |
( |
An object of class minimax generated with locally().
For Emax_known = TRUE, the design has 7 support points. Otherwise,
it has 8.
td_opt_1 <- td_opt(param = c(h = 2, delta = 0.2, gamma = 1.3, c0 = 0.2),
Emax_known = TRUE,
ICA.control = list(ncount = 300, rseed = 1905, trace = FALSE),
iter = 600)
td_opt_1
plot_td_des(td_opt_1)
plot_td_dcrit_equ(td_opt_1)
td_opt_2 <- td_opt(param = c(h = 2, delta = 0.2, gamma = 1.3, c0 = 0.2),
Emax_known = FALSE,
ICA.control = list(ncount = 300, rseed = 1905, revol_rate = 0.5, trace = FALSE),
iter = 600)
td_opt_2
plot_td_des(td_opt_2)
plot_td_dcrit_equ(td_opt_2)
td_opt_3 <- td_opt(param = c(h = 1, delta = 0.5, gamma = 2, c0 = 0.01),
Emax_known = TRUE, ICA.control = list(ncount = 300, rseed = 1905, trace = FALSE),
iter = 1000)
plot_td_des(td_opt_3)
plot_td_dcrit_equ(td_opt_3, plot_theta = 100, n_grid = 100, dose_lim = c(0, 0.2))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.